@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-07-10'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2015-07-12'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,6 +22,8 @@ use namespace::autoclean;
 use App::GenPericmdScript qw(gen_perinci_cmdline_script);
 use Module::Load;
 
+has build_load_modules => (is=>'rw');
+
 has url => (is=>'rw', required=>1);
 has subcommands => (is=>'rw');
 has subcommands_from_package_functions => (is=>'rw');
@@ -101,6 +103,13 @@ sub munge_files {
         my $mods_tempdir = $self->written_modules_dir;
 
         local @INC = ($mods_tempdir, @INC);
+
+        if ($self->build_load_modules) {
+            for (split(/\s*,\s*/, $self->build_load_modules)) {
+                load $_;
+            }
+        }
+
         $res = gen_perinci_cmdline_script(
             url => $self->url,
             script_name => $scriptname,
@@ -178,7 +187,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.19 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-10.
+This document describes version 0.20 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-12.
 
 =head1 SYNOPSIS
 
@@ -240,7 +249,7 @@ e.g.:
 
 =for Pod::Coverage .+
 
-=head1 CONFIGURATION
+=head1 CONFIGURATION (SCRIPT SPECIFICATION)
 
 =head2 url* => str
 
@@ -326,6 +335,12 @@ This is like the configuration, but per-script.
 
 Passed to Perinci::CmdLine object construction code.
 
+=head1 CONFIGURATION (OTHER)
+
+=head2 build_load_modules => str
+
+A comma-separated string. Load module(s) during build process.
+
 =head1 SEE ALSO
 
 L<Rinci>
@@ -341,7 +356,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
 
 =head1 BUGS
 
